@@ -1,7 +1,7 @@
 package Bencher::Scenario::WordListModules;
 
 our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,7 +37,7 @@ Bencher::Scenario::WordListModules - Benchmark startup overhead of WordList::* m
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::WordListModules (from Perl distribution Bencher-Scenario-WordListModules), released on 2016-01-08.
+This document describes version 0.03 of Bencher::Scenario::WordListModules (from Perl distribution Bencher-Scenario-WordListModules), released on 2016-01-08.
 
 =head1 SYNOPSIS
 
@@ -120,20 +120,24 @@ Benchmark with default option:
  +-----+----------------------------------------+--------+-------------------+---------+---------+
  | seq | name                                   | time   | mod_overhead_time | errors  | samples |
  +-----+----------------------------------------+--------+-------------------+---------+---------+
- | 2   | WordList::EN::CountryNames::SingleWord | 5.5ms  | 1.2ms             | 2.7e-05 | 46      |
+ | 1   | WordList::EN::CountryNames             | 5.7ms  | 1.3ms             | 2.8e-05 | 60      |
+ | 5   | WordList::ID::KBBI                     | 5.6ms  | 1.2ms             | 2.5e-05 | 54      |
  | 6   | WordList::Phrase::EN::Proverb::TWW     | 5.5ms  | 1.1ms             | 2.1e-05 | 20      |
- | 7   | WordList::Phrase::ID::Proverb::KBBI    | 5.4ms  | 1.1ms             | 2.6e-05 | 40      |
- | 5   | WordList::ID::KBBI                     | 5.38ms | 1.04ms            | 1.5e-05 | 20      |
- | 1   | WordList::EN::CountryNames             | 5.3ms  | 0.97ms            | 2.2e-05 | 20      |
- | 4   | WordList::EN::SGB                      | 5.3ms  | 0.92ms            | 1.7e-05 | 20      |
- | 3   | WordList::EN::Enable                   | 5.22ms | 0.882ms           | 1.4e-05 | 20      |
- | 0   | perl -e1 (baseline)                    | 4.3ms  | 0ms               | 1.8e-05 | 24      |
+ | 7   | WordList::Phrase::ID::Proverb::KBBI    | 5.47ms | 1.04ms            | 1.5e-05 | 20      |
+ | 3   | WordList::EN::Enable                   | 5.4ms  | 0.98ms            | 2e-05   | 21      |
+ | 4   | WordList::EN::SGB                      | 5.4ms  | 0.93ms            | 2.3e-05 | 20      |
+ | 2   | WordList::EN::CountryNames::SingleWord | 5.3ms  | 0.91ms            | 2.4e-05 | 20      |
+ | 0   | perl -e1 (baseline)                    | 4.4ms  | 0ms               | 2.1e-05 | 127     |
  +-----+----------------------------------------+--------+-------------------+---------+---------+
 
 =head1 DESCRIPTION
 
 Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
+=head1 SEE ALSO
+
+L<Bencher::Scenario::GamesWordlistModules>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-WordListModules>.
